Struct
QmiMessageNasSwiGetStatusOutput
since: 1.24
Description [src]
struct QmiMessageNasSwiGetStatusOutput {
/* No available fields */
}
The QmiMessageNasSwiGetStatusOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.24
Instance methods
qmi_message_nas_swi_get_status_output_get_common_info_v2
Get the ‘Common Info v2’ field from self.
since: 1.30
qmi_message_nas_swi_get_status_output_ref
Atomically increments the reference count of self by one.
since: 1.24
qmi_message_nas_swi_get_status_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.24